==> kubernetes-model-core-5.8.0-sources.jar: io/fabric8/kubernetes/api/model/VsphereVirtualDiskVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
public class VsphereVirtualDiskVolumeSourceFluentImpl<A extends io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSourceFluent<A>{
  public VsphereVirtualDiskVolumeSourceFluentImpl() {
  }
  public VsphereVirtualDiskVolumeSourceFluentImpl(io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSource instance) {
    this.withFsType(instance.getFsType()); 
    this.withStoragePolicyID(instance.getStoragePolicyID()); 
    this.withStoragePolicyName(instance.getStoragePolicyName()); 
    this.withVolumePath(instance.getVolumePath()); 
  }
  private java.lang.String fsType;
  private java.lang.String storagePolicyID;
  private java.lang.String storagePolicyName;
  private java.lang.String volumePath;
  public java.lang.String getFsType() {
    return this.fsType;
  }
  public A withFsType(java.lang.String fsType) {
    this.fsType=fsType; return (A) this;
  }
  public java.lang.Boolean hasFsType() {
    return this.fsType != null;
  }
  
  /**
   * Method is deprecated. use withFsType instead.
   */
  @java.lang.Deprecated
  public A withNewFsType(java.lang.String arg0) {
    return (A)withFsType(new String(arg0));
  }
  public java.lang.String getStoragePolicyID() {
    return this.storagePolicyID;
  }
  public A withStoragePolicyID(java.lang.String storagePolicyID) {
    this.storagePolicyID=storagePolicyID; return (A) this;
  }
  public java.lang.Boolean hasStoragePolicyID() {
    return this.storagePolicyID != null;
  }
  
  /**
   * Method is deprecated. use withStoragePolicyID instead.
   */
  @java.lang.Deprecated
  public A withNewStoragePolicyID(java.lang.String arg0) {
    return (A)withStoragePolicyID(new String(arg0));
  }
  public java.lang.String getStoragePolicyName() {
    return this.storagePolicyName;
  }
  public A withStoragePolicyName(java.lang.String storagePolicyName) {
    this.storagePolicyName=storagePolicyName; return (A) this;
  }
  public java.lang.Boolean hasStoragePolicyName() {
    return this.storagePolicyName != null;
  }
  
  /**
   * Method is deprecated. use withStoragePolicyName instead.
   */
  @java.lang.Deprecated
  public A withNewStoragePolicyName(java.lang.String arg0) {
    return (A)withStoragePolicyName(new String(arg0));
  }
  public java.lang.String getVolumePath() {
    return this.volumePath;
  }
  public A withVolumePath(java.lang.String volumePath) {
    this.volumePath=volumePath; return (A) this;
  }
  public java.lang.Boolean hasVolumePath() {
    return this.volumePath != null;
  }
  
  /**
   * Method is deprecated. use withVolumePath instead.
   */
  @java.lang.Deprecated
  public A withNewVolumePath(java.lang.String arg0) {
    return (A)withVolumePath(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    VsphereVirtualDiskVolumeSourceFluentImpl that = (VsphereVirtualDiskVolumeSourceFluentImpl) o;
    if (fsType != null ? !fsType.equals(that.fsType) :that.fsType != null) return false;
    if (storagePolicyID != null ? !storagePolicyID.equals(that.storagePolicyID) :that.storagePolicyID != null) return false;
    if (storagePolicyName != null ? !storagePolicyName.equals(that.storagePolicyName) :that.storagePolicyName != null) return false;
    if (volumePath != null ? !volumePath.equals(that.volumePath) :that.volumePath != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fsType,  storagePolicyID,  storagePolicyName,  volumePath,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.11.2-sources.jar: io/fabric8/kubernetes/api/model/VsphereVirtualDiskVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class VsphereVirtualDiskVolumeSourceFluentImpl<A extends io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSourceFluent<A>{
  public VsphereVirtualDiskVolumeSourceFluentImpl() {
  }
  public VsphereVirtualDiskVolumeSourceFluentImpl(io.fabric8.kubernetes.api.model.VsphereVirtualDiskVolumeSource instance) {
    this.withFsType(instance.getFsType()); 
    this.withStoragePolicyID(instance.getStoragePolicyID()); 
    this.withStoragePolicyName(instance.getStoragePolicyName()); 
    this.withVolumePath(instance.getVolumePath()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String fsType;
  private java.lang.String storagePolicyID;
  private java.lang.String storagePolicyName;
  private java.lang.String volumePath;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getFsType() {
    return this.fsType;
  }
  public A withFsType(java.lang.String fsType) {
    this.fsType=fsType; return (A) this;
  }
  public java.lang.Boolean hasFsType() {
    return this.fsType != null;
  }
  
  /**
   * Method is deprecated. use withFsType instead.
   */
  @java.lang.Deprecated
  public A withNewFsType(java.lang.String arg0) {
    return (A)withFsType(new String(arg0));
  }
  public java.lang.String getStoragePolicyID() {
    return this.storagePolicyID;
  }
  public A withStoragePolicyID(java.lang.String storagePolicyID) {
    this.storagePolicyID=storagePolicyID; return (A) this;
  }
  public java.lang.Boolean hasStoragePolicyID() {
    return this.storagePolicyID != null;
  }
  
  /**
   * Method is deprecated. use withStoragePolicyID instead.
   */
  @java.lang.Deprecated
  public A withNewStoragePolicyID(java.lang.String arg0) {
    return (A)withStoragePolicyID(new String(arg0));
  }
  public java.lang.String getStoragePolicyName() {
    return this.storagePolicyName;
  }
  public A withStoragePolicyName(java.lang.String storagePolicyName) {
    this.storagePolicyName=storagePolicyName; return (A) this;
  }
  public java.lang.Boolean hasStoragePolicyName() {
    return this.storagePolicyName != null;
  }
  
  /**
   * Method is deprecated. use withStoragePolicyName instead.
   */
  @java.lang.Deprecated
  public A withNewStoragePolicyName(java.lang.String arg0) {
    return (A)withStoragePolicyName(new String(arg0));
  }
  public java.lang.String getVolumePath() {
    return this.volumePath;
  }
  public A withVolumePath(java.lang.String volumePath) {
    this.volumePath=volumePath; return (A) this;
  }
  public java.lang.Boolean hasVolumePath() {
    return this.volumePath != null;
  }
  
  /**
   * Method is deprecated. use withVolumePath instead.
   */
  @java.lang.Deprecated
  public A withNewVolumePath(java.lang.String arg0) {
    return (A)withVolumePath(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    VsphereVirtualDiskVolumeSourceFluentImpl that = (VsphereVirtualDiskVolumeSourceFluentImpl) o;
    if (fsType != null ? !fsType.equals(that.fsType) :that.fsType != null) return false;
    if (storagePolicyID != null ? !storagePolicyID.equals(that.storagePolicyID) :that.storagePolicyID != null) return false;
    if (storagePolicyName != null ? !storagePolicyName.equals(that.storagePolicyName) :that.storagePolicyName != null) return false;
    if (volumePath != null ? !volumePath.equals(that.volumePath) :that.volumePath != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fsType,  storagePolicyID,  storagePolicyName,  volumePath,  additionalProperties,  super.hashCode());
  }
  
}
